# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
from future import standard_library
import pbr.version

from redfish.main import connect  # noqa: F401
standard_library.install_aliases()

try:
    __version__ = pbr.version.VersionInfo('redfish').release_string()
except Exception as e:
    if "Versioning for this project requires either an sdist tarball" \
       in e.args[0]:
        pass
    else:
        raise
